@@ -15,27 +15,18 @@ When this module is directly run from the terminal a demo will be shown.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"  # 0.0.1 was stamped 01-08-2018
-__version__ = "0.0.5"  # 0.0.1 corresponds to prototype 1.0.0
+__date__ = "15-07-2020"
+__version__ = "0.0.6"
 # pylint: disable=bare-except, broad-except, try-except-raise, pointless-string-statement
 
 import sys
-from pathlib import Path
-
-import serial
-import serial.tools.list_ports
+from typing import Union
 import numpy as np
 
-from dvg_debug_functions import print_fancy_traceback as pft
-
-# Serial settings
-RS232_BAUDRATE = 115200
-RS232_TIMEOUT = 0.4  # [s]
-RS232_RTSCTS = True
-TERM_CHAR = "\r"
+from dvg_devices.BaseDevice import SerialDevice
 
 
-class Compax3_servo:
+class Compax3_servo(SerialDevice):
     """Containers for the process and measurement variables
     [numpy.nan] values indicate that the parameter is not initialized or that
     the last query was unsuccessful in communication.
@@ -69,193 +60,74 @@ class Compax3_servo:
         error_msg = np.nan          # error string message
         # fmt: on
 
-    def __init__(self, name="trav"):
-        self.ser = None  # serial.Serial device instance
-        self.name = name
-        self.serial_str = None  # Serial number of the Compax3
+    def __init__(
+        self,
+        name="trav",
+        long_name="Compax3 servo",
+        connect_to_serial_number=None,
+    ):
+        super().__init__(name=name, long_name=long_name)
 
-        # Is the connection to the device alive?
-        self.is_alive = False
+        # Default serial settings
+        self.serial_init_kwargs = {
+            "baudrate": 115200,
+            "timeout": 0.4,
+            "write_timeout": 0.4,
+            "rtscts": True,
+        }
+        self.set_read_termination("\r")
+        self.set_write_termination("\r")
+
+        self.set_ID_validation_query(
+            ID_validation_query=self.ID_validation_query,
+            valid_ID_broad="Compax3",
+            valid_ID_specific=connect_to_serial_number,
+        )
 
         # Containers for the status, process and measurement variables
         self.status_word_1 = self.Status_word_1()
         self.state = self.State()
 
-    # --------------------------------------------------------------------------
-    #   close
-    # --------------------------------------------------------------------------
-
-    def close(self, ignore_exceptions=False):
-        """Close the serial port
-        """
-        if self.ser is not None:
-            try:
-                self.ser.close()
-            except:
-                if ignore_exceptions:
-                    pass
-                else:
-                    raise
-
-        self.is_alive = False
+        self.serial_str = None  # Serial number of the Compax3
 
     # --------------------------------------------------------------------------
-    #   connect_at_port
+    #   OVERRIDE: query
     # --------------------------------------------------------------------------
 
-    def connect_at_port(
-        self, port_str, match_serial_str=None, print_trying_message=True
-    ):
-        """Open the port at address 'port_str' and try to establish a
-        connection. A query for the Compax3 serial number is send over the port.
-        If it gives the proper response (and optionally has a matching serial
-        number) it must be the Compax3 servo we're looking for.
-
-        Args:
-            port_str (str): Serial port address to open
-            match_serial_str (str, optional): Serial string of the Compax3 to
-                establish a connection to. When empty or None then any Compax3
-                is accepted. Defaults to None.
-            print_trying_message (bool, optional): When True then a 'trying to
-                open' message is printed to the terminal. Defaults to True.
-
-        Returns: True if successful, False otherwise.
-        """
-        self.is_alive = False
-
-        if match_serial_str == "":
-            match_serial_str = None
-        if print_trying_message:
-            if match_serial_str is None:
-                print("Connect to: Compax3 servo")
-            else:
-                print("Connect to: Compax3 servo, serial %s" % match_serial_str)
-
-        print("  @ %-5s: " % port_str, end="")
-        try:
-            # Open the serial port
-            self.ser = serial.Serial(
-                port=port_str,
-                baudrate=RS232_BAUDRATE,
-                rtscts=RS232_RTSCTS,
-                timeout=RS232_TIMEOUT,
-                write_timeout=RS232_TIMEOUT,
-            )
-        except serial.SerialException:
-            print("Could not open port")
-            return False
-        except:
-            raise
-
-        try:
-            # Query the serial number string.
-            # NOTE: this function can finish okay and return False as indication
-            # that the device on the serial port gives /a/ reply but it is not a
-            # proper reply you would except from a Compax3 servo. In other
-            # words: the device replies but it is not a Compax3 servo.
-            self.is_alive = True
-            success = self.query_serial_str()
-        except:
-            print("Communication error")
-            if self.ser is not None:
-                self.ser.close()
-            self.is_alive = False
-            return False
+    def query(
+        self,
+        msg: Union[str, bytes],
+        raises_on_timeout: bool = False,
+        returns_ascii: bool = True,
+    ) -> tuple:
+        success, reply = super().query(msg, raises_on_timeout, returns_ascii)
 
+        # The Compax3 is more complex in its replies than the average device.
+        # Hence:
         if success:
-            print("serial %s: " % self.serial_str, end="")
-            if match_serial_str is None:
-                # Found any Compax3 servo
-                print("Success!")
-                print("  Name: '%s'\n" % self.name)
-                self.is_alive = True
-                return True
-            elif self.serial_str.lower() == match_serial_str.lower():
-                # Found the Compax3 servo with matching serial
-                print("Success!")
-                print("  Name: '%s'\n" % self.name)
-                self.is_alive = True
-                return True
-
-        print("Wrong or no device")
-        if self.ser is not None:
-            self.ser.close()
-        self.is_alive = False
-        return False
-
-    # --------------------------------------------------------------------------
-    #   scan_ports
-    # --------------------------------------------------------------------------
-
-    def scan_ports(self, match_serial_str=None):
-        """Scan over all serial ports and try to establish a connection. A query
-        for the Compax3 serial number is send over all ports. The port that
-        gives the proper response (and optionally has a matching serial number)
-        must be the Compax3 servo we're looking for.
-
-        Args:
-            match_serial_str (str, optional): Serial string of the Compax3 to
-                establish a connection to. When empty or None then any Compax3
-                is accepted. Defaults to None.
-
-        Returns: True if successful, False otherwise.
-        """
-        if match_serial_str == "":
-            match_serial_str = None
-        if match_serial_str is None:
-            print("Scanning ports for any Compax3 servo ")
-        else:
-            print(
-                (
-                    "Scanning ports for a Compax3 servo with\n"
-                    "serial number '%s'"
-                )
-                % match_serial_str
-            )
-
-        # Ports is a list of tuples
-        ports = list(serial.tools.list_ports.comports())
-        for p in ports:
-            port_str = p[0]
-            if self.connect_at_port(port_str, match_serial_str, False):
-                return True
+            if reply[0] == ">":
+                # Successful operation without meaningful reply
+                pass
+            elif reply[0] == "!":
+                # Error reply
+                print("COMPAX3 COMMUNICATION ERROR: " + reply)
+                success = False
             else:
-                continue
+                # Successful operation with meaningful reply
+                pass
 
-        # Scanned over all the ports without finding a match
-        print("\n  ERROR: Device not found")
-        return False
+        return (success, reply)
 
     # --------------------------------------------------------------------------
-    #   auto_connect
+    #   ID_validation_query
     # --------------------------------------------------------------------------
 
-    def auto_connect(self, path_config, match_serial_str=None):
-        """TO DO: write explaination
-        """
-        # Try to open the config file containing the port to open. Do not panic
-        # if the file does not exist or cannot be read. We will then scan over
-        # all ports as alternative.
-        port_str = read_port_config_file(path_config)
-
-        # If the config file was read successfully then we can try to open the
-        # port listed in the config file and connect to the device.
-        if port_str is not None:
-            success = self.connect_at_port(port_str, match_serial_str)
-        else:
-            success = False
-
-        # Check if we failed establishing a connection
-        if not success:
-            # Now scan over all ports and try to connect to the device
-            success = self.scan_ports(match_serial_str)
-            if success:
-                # Store the result of a successful connection after a port scan
-                # in the config file. Do not panic if we cannot create the
-                # config file.
-                write_port_config_file(path_config, self.ser.portstr)
-
-        return success
+    def ID_validation_query(self) -> (str, str):
+        _success, reply = self.query("_?")
+        broad_reply = reply[:7]  # Expected: "Compax3"
+        _success, reply = self.query("o1.4")
+        specific_reply = reply  # Serial number
+        return (broad_reply, specific_reply)
 
     # --------------------------------------------------------------------------
     #   begin
@@ -267,70 +139,12 @@ class Compax3_servo:
 
         Returns: True if successful, False otherwise.
         """
-        success = self.query_error()
+        success = self.query_serial_str()
+        success &= self.query_error()
         success &= self.query_position()
         success &= self.query_status_word_1()
-
         return success
 
-    # --------------------------------------------------------------------------
-    #   query
-    # --------------------------------------------------------------------------
-
-    def query(self, msg_str):
-        """Send a command to the serial device and subsequently read the reply.
-
-        Args:
-            msg_str (str): Message to be sent to the serial device.
-
-        Returns:
-            success (bool): True if successful, False otherwise.
-            ans_str (str) : Reply received from the device. [None] if
-                            unsuccessful.
-        """
-        success = False
-        ans_str = None
-
-        if not self.is_alive:
-            pft("Device is not connected yet or already closed.", 3)
-        else:
-            try:
-                # Send command string to the device as bytes
-                self.ser.write((msg_str + TERM_CHAR).encode())
-            except (
-                serial.SerialTimeoutException,
-                serial.SerialException,
-            ) as err:
-                # Print error and struggle on
-                pft(err, 3)
-            except Exception as err:
-                pft(err, 3)
-                sys.exit(0)
-            else:
-                try:
-                    ans_bytes = self.ser.read_until(TERM_CHAR.encode())
-                except (
-                    serial.SerialTimeoutException,
-                    serial.SerialException,
-                ) as err:
-                    pft(err, 3)
-                except Exception as err:
-                    pft(err, 3)
-                    sys.exit(0)
-                else:
-                    ans_str = ans_bytes.decode("utf8").strip()
-                    if ans_str[0] == ">":
-                        # Successfull operation without meaningfull reply
-                        success = True
-                    elif ans_str[0] == "!":
-                        # Error reply
-                        print("COMPAX3 COMMUNICATION ERROR: " + ans_str)
-                    else:
-                        # Successfull operation with meaningfull reply
-                        success = True
-
-        return [success, ans_str]
-
     # --------------------------------------------------------------------------
     #   Higher level queries
     # --------------------------------------------------------------------------
@@ -344,12 +158,12 @@ class Compax3_servo:
         # have to exclude the possibility that another device will reply with
         # an error message to the serial number request, which then could be
         # mistaken for /the/ serial number.
-        [success, ans_str] = self.query("_?")
-        if success and ans_str.startswith("Compax3"):
+        success, reply = self.query("_?")
+        if success and reply.startswith("Compax3"):
             # Now we can query the serial number
-            [success, ans_str] = self.query("o1.4")
+            success, reply = self.query("o1.4")
             if success:
-                self.serial_str = ans_str
+                self.serial_str = reply
                 return True
 
         self.serial_str = None
@@ -357,14 +171,14 @@ class Compax3_servo:
 
     def query_position(self):
         """Query the position and store in the class member 'state.cur_pos'
-        when successfull. When the communication fails the class member will be
+        when successful. When the communication fails the class member will be
         set to [numpy.nan].
 
         Returns: True if successful, False otherwise.
         """
-        [success, ans_str] = self.query("o680.5")
+        success, reply = self.query("o680.5")
         if success:
-            self.state.cur_pos = float(ans_str)
+            self.state.cur_pos = float(reply)
         else:
             self.state.cur_pos = np.nan
 
@@ -372,36 +186,36 @@ class Compax3_servo:
 
     def query_error(self):
         """Query the last error and store in the class member 'state.error_msg'
-        when successfull. When the communication fails the class member will be
+        when successful. When the communication fails the class member will be
         set to [numpy.nan].
 
         Returns: True if successful, False otherwise.
         """
-        [success, ans_str] = self.query("o550.1")
+        success, reply = self.query("o550.1")
         if success:
             # Translate error codes to more meaningful messages
-            if ans_str == "1":
+            if reply == "1":
                 self.state.error_msg = ""
-            elif ans_str == "17168":
-                self.state.error_msg = "%s: Motor temperature" % ans_str
-            elif ans_str == "29472":
-                self.state.error_msg = "%s: Following error" % ans_str
-            elif ans_str == "29475":
+            elif reply == "17168":
+                self.state.error_msg = "%s: Motor temperature" % reply
+            elif reply == "29472":
+                self.state.error_msg = "%s: Following error" % reply
+            elif reply == "29475":
                 self.state.error_msg = (
                     "%s: Target or actual position "
-                    "exceeds positive end limit" % ans_str
+                    "exceeds positive end limit" % reply
                 )
-            elif ans_str == "29476":
+            elif reply == "29476":
                 self.state.error_msg = (
                     "%s: Target or actual position "
-                    "exceeds negative end limit" % ans_str
+                    "exceeds negative end limit" % reply
                 )
-            elif ans_str == "29479":
+            elif reply == "29479":
                 self.state.error_msg = (
-                    "%s: Change of direction during " "movement" % ans_str
+                    "%s: Change of direction during " "movement" % reply
                 )
             else:
-                self.state.error_msg = ans_str
+                self.state.error_msg = reply
         else:
             self.state.error_msg = np.nan
 
@@ -409,14 +223,14 @@ class Compax3_servo:
 
     def query_status_word_1(self):
         """Query the status word 1 and store in the class member 'status_word_1'
-        when successfull. When the communication fails the class member
+        when successful. When the communication fails the class member
         'status_word_1' will be populated with [numpy.nan].
 
         Returns: True if successful, False otherwise.
         """
-        [success, ans_str] = self.query("o1000.3")
+        success, reply = self.query("o1000.3")
 
-        if ans_str is None:
+        if reply is None:
             # fmt: off
             self.status_word_1.I0 = np.nan
             self.status_word_1.I1 = np.nan
@@ -436,7 +250,7 @@ class Compax3_servo:
             self.status_word_1.PSB2 = np.nan
             # fmt: on
         else:
-            dec_x = int(ans_str)
+            dec_x = int(reply)
 
             # Convert dec to bin string, remove prefix '0b', prefix with 0's to
             # garantuee 16 bits and reverse
@@ -491,31 +305,29 @@ class Compax3_servo:
         print("    decel = %.2f" % decel)
         print("    jerk  = %.2f\n" % jerk)
 
-        [success, _ans_str] = self.query(
+        success, _reply = self.query(
             "o1901.%d=%.2f" % (profile_number, target_position)
         )
         if success:
-            [success, _ans_str] = self.query(
+            success, _reply = self.query(
                 "o1902.%d=%.2f" % (profile_number, velocity)
             )
         if success:
-            [success, _ans_str] = self.query(
-                "o1905.%d=%d" % (profile_number, mode)
-            )
+            success, _reply = self.query("o1905.%d=%d" % (profile_number, mode))
         if success:
-            [success, _ans_str] = self.query(
+            success, _reply = self.query(
                 "o1906.%d=%.2f" % (profile_number, accel)
             )
         if success:
-            [success, _ans_str] = self.query(
+            success, _reply = self.query(
                 "o1907.%d=%.2f" % (profile_number, decel)
             )
         if success:
-            [success, _ans_str] = self.query(
+            success, _reply = self.query(
                 "o1908.%d=%.2f" % (profile_number, jerk)
             )
         if success:
-            [success, _ans_str] = self.query(
+            success, _reply = self.query(
                 "o1904.%d=$32" % (profile_number)
             )  # Store profile
 
@@ -530,11 +342,11 @@ class Compax3_servo:
         #             start bit (bit 13) low
         CW_LO = 0b0100000000000011
         CW_LO = CW_LO + (profile_number << 8)
-        [success, _ans_str] = self.query("o1100.3=%d" % CW_LO)
+        success, _reply = self.query("o1100.3=%d" % CW_LO)
         if success:
             # Then send start bit (bit 13) high
             CW_HI = CW_LO + (1 << 13)
-            [success, _ans_str] = self.query("o1100.3=%d" % CW_HI)
+            success, _reply = self.query("o1100.3=%d" % CW_HI)
 
         return success
 
@@ -544,7 +356,7 @@ class Compax3_servo:
         at least once with 'self.store_motion_profile' before moving.
         """
         # Send new target position
-        [success, _ans_str] = self.query(
+        success, _reply = self.query(
             "o1901.%d=%.2f" % (profile_number, target_position)
         )
 
@@ -558,11 +370,11 @@ class Compax3_servo:
         """
         # Control word (CW) for activating the jog+
         CW_LO = 0b0100000000000011
-        [success, _ans_str] = self.query("o1100.3=%d" % CW_LO)
+        success, _reply = self.query("o1100.3=%d" % CW_LO)
         if success:
             # Then send jog+ bit (bit 2) high
             CW_HI = CW_LO + (1 << 2)
-            [success, _ans_str] = self.query("o1100.3=%d" % CW_HI)
+            success, _reply = self.query("o1100.3=%d" % CW_HI)
 
         return success
 
@@ -571,11 +383,11 @@ class Compax3_servo:
         """
         # Control word (CW) for activating the jog-
         CW_LO = 0b0100000000000011
-        [success, _ans_str] = self.query("o1100.3=%d" % CW_LO)
+        success, _reply = self.query("o1100.3=%d" % CW_LO)
         if success:
             # Then send jog- bit (bit 3) high
             CW_HI = CW_LO + (1 << 3)
-            [success, _ans_str] = self.query("o1100.3=%d" % CW_HI)
+            success, _reply = self.query("o1100.3=%d" % CW_HI)
 
         return success
 
@@ -583,14 +395,14 @@ class Compax3_servo:
         """
         """
         CW_LO = 0b0100000000000011
-        [success, _ans_str] = self.query("o1100.3=%d" % CW_LO)
+        success, _reply = self.query("o1100.3=%d" % CW_LO)
 
         return success
 
     def stop_motion_and_remove_power(self):
         """
         """
-        [success, _ans_str] = self.query("o1100.3=0")
+        success, _reply = self.query("o1100.3=0")
 
         return success
 
@@ -604,9 +416,9 @@ class Compax3_servo:
 
         Returns: True if successful, False otherwise.
         """
-        [success, _ans_str] = self.query("o1100.3=0")
+        success, _reply = self.query("o1100.3=0")
         if success:
-            [success, _ans_str] = self.query("o1100.3=1")
+            success, _reply = self.query("o1100.3=1")
 
         return success
 
@@ -654,68 +466,6 @@ class Compax3_servo:
         print("")
 
 
-# -----------------------------------------------------------------------------
-#   read_port_config_file
-# -----------------------------------------------------------------------------
-
-
-def read_port_config_file(filepath):
-    """Try to open the config textfile containing the port to open. Do not panic
-    if the file does not exist or cannot be read.
-
-    Args:
-        filepath (pathlib.Path): path to the config file,
-            e.g. Path("config/port.txt")
-
-    Returns: The port name string when the config file is read out successfully,
-        None otherwise.
-    """
-    if isinstance(filepath, Path):
-        if filepath.is_file():
-            try:
-                with filepath.open() as f:
-                    port_str = f.readline().strip()
-                return port_str
-            except:
-                pass  # Do not panic and remain silent
-
-    return None
-
-
-# -----------------------------------------------------------------------------
-#   write_port_config_file
-# -----------------------------------------------------------------------------
-
-
-def write_port_config_file(filepath, port_str):
-    """Try to write the port name string to the config textfile. Do not panic if
-    the file cannot be created.
-
-    Args:
-        filepath (pathlib.Path): path to the config file,
-            e.g. Path("config/port.txt")
-        port_str (string): COM port string to save to file
-    Returns: True when successful, False otherwise.
-    """
-    if isinstance(filepath, Path):
-        if not filepath.parent.is_dir():
-            # Subfolder does not exists yet. Create.
-            try:
-                filepath.parent.mkdir()
-            except:
-                pass  # Do not panic and remain silent
-
-        try:
-            # Write the config file
-            filepath.write_text(port_str)
-        except:
-            pass  # Do not panic and remain silent
-        else:
-            return True
-
-    return False
-
-
 # ------------------------------------------------------------------------------
 #   Main: Will show a demo when run from the terminal
 # ------------------------------------------------------------------------------
@@ -731,19 +481,19 @@ if __name__ == "__main__":
         # Display name
         name = "TRAV"
         # Path to the config textfile containing the (last used) RS232 port
-        path_config = Path("config/port_Compax3_servo.txt")
+        path_config = "config/port_Compax3_servo.txt"
 
     # Horizontal axis
     trav_conn_horz = Trav_connection_params()
     trav_conn_horz.serial = "4409980001"
     trav_conn_horz.name = "TRAV HORZ"
-    trav_conn_horz.path_config = Path("config/port_Compax3_servo_horz.txt")
+    trav_conn_horz.path_config = "config/port_Compax3_servo_horz.txt"
 
     # Vertical axis
     trav_conn_vert = Trav_connection_params()
     trav_conn_vert.serial = "4319370001"
     trav_conn_vert.name = "TRAV VERT"
-    trav_conn_vert.path_config = Path("config/port_Compax3_servo_vert.txt")
+    trav_conn_vert.path_config = "config/port_Compax3_servo_vert.txt"
 
     # Connect to this specific traverse axis
     # trav_conn = Trav_connection_params()  # Any
@@ -754,9 +504,11 @@ if __name__ == "__main__":
     # --------------------------------------------------------------------------
 
     # Create connection to Compax3 servo controller over RS232
-    trav = Compax3_servo(name=trav_conn.name)
+    trav = Compax3_servo(
+        name=trav_conn.name, connect_to_serial_number=trav_conn.serial
+    )
 
-    if trav.auto_connect(trav_conn.path_config, trav_conn.serial):
+    if trav.auto_connect(filepath_last_known_port=trav_conn.path_config):
         trav.begin()  # Retrieve necessary parameters
     else:
         time.sleep(1)
