@@ -6,8 +6,8 @@ acquisition for a Compax3 traverse controller.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "06-07-2020"  # 0.0.1 was stamped 14-09-2018
-__version__ = "0.0.5"  # 0.0.1 corresponds to prototype 1.0.0
+__date__ = "06-07-2020"
+__version__ = "0.0.6"
 # pylint: disable=try-except-raise
 
 from PyQt5 import QtCore, QtGui
@@ -32,42 +32,22 @@ class Compax3_servo_qdev(QDeviceIO):
     These can be incorporated into your application.
 
     All device I/O operations will be offloaded to 'workers', each running in
-    a newly created thread instead of in the main/GUI thread.
-
-        - Worker_DAQ:
-            Periodically acquires data from the device.
-
-        - Worker_jobs:
-            Maintains a thread-safe queue where desired device I/O operations
-            can be put onto, and sends the queued operations first in first out
-            (FIFO) to the device.
+    a newly created thread.
 
     (*): See 'dvg_qdeviceio.QDeviceIO()' for details.
 
     Args:
         dev:
-            Reference to a 'dvg_devices.Compax3_servo_protocol_RS232.Compax3_servo'
+            Reference to a
+            'dvg_devices.Compax3_servo_protocol_RS232.Compax3_servo'
             instance.
 
-        (*) DAQ_interval_ms
-        (*) critical_not_alive_count
-        (*) DAQ_timer_type
-
-    Main methods:
-        (*) start(...)
-        (*) quit()
-
-    Main data attributes:
-        (*) DAQ_update_counter
-        (*) obtained_DAQ_interval_ms
-        (*) obtained_DAQ_rate_Hz
+        debug:
+            Show debug info in terminal? Warning: Slow! Do not leave on
+            unintentionally.
 
     Main GUI objects:
         qgrp (PyQt5.QtWidgets.QGroupBox)
-
-    Signals:
-        (*) signal_DAQ_updated()
-        (*) signal_connection_lost()
     """
 
     def __init__(
@@ -84,7 +64,7 @@ class Compax3_servo_qdev(QDeviceIO):
 
         self.create_worker_DAQ(
             DAQ_trigger=DAQ_TRIGGER.INTERNAL_TIMER,
-            DAQ_function=self.DAQ_function,
+            DAQ_function=self._DAQ_function,
             DAQ_interval_ms=DAQ_interval_ms,
             DAQ_timer_type=DAQ_timer_type,
             critical_not_alive_count=critical_not_alive_count,
@@ -94,21 +74,22 @@ class Compax3_servo_qdev(QDeviceIO):
 
         self.create_worker_jobs(debug=debug)
 
-        self.create_GUI()
-        self.signal_DAQ_updated.connect(self.update_GUI)
-        self.connect_signals_to_slots()
+        self._create_GUI()
+        self._connect_signals_to_slots()
+        self.signal_DAQ_updated.connect(self._update_GUI)
+
         if not self.dev.is_alive:
-            self.update_GUI()  # Correctly reflect an offline device
+            self._update_GUI()  # Correctly reflect an offline device
 
         # Flags for Jog+/Jog- pushbutton control
-        self.jog_plus_is_active = False
-        self.jog_minus_is_active = False
+        self._jog_plus_is_active = False
+        self._jog_minus_is_active = False
 
     # --------------------------------------------------------------------------
-    #   DAQ_function
+    #   _DAQ_function
     # --------------------------------------------------------------------------
 
-    def DAQ_function(self):
+    def _DAQ_function(self):
         success = self.dev.query_position()
         success &= self.dev.query_status_word_1()
 
@@ -118,10 +99,10 @@ class Compax3_servo_qdev(QDeviceIO):
         return success
 
     # --------------------------------------------------------------------------
-    #   create_GUI
+    #   _create_GUI
     # --------------------------------------------------------------------------
 
-    def create_GUI(self):
+    def _create_GUI(self):
         default_font_height = 17
         default_font_width = 8
 
@@ -218,11 +199,11 @@ class Compax3_servo_qdev(QDeviceIO):
         self.qgrp.setMaximumWidth(200)  # Work=around, hard limit width
 
     # --------------------------------------------------------------------------
-    #   update_GUI
+    #   _update_GUI
     # --------------------------------------------------------------------------
 
     @QtCore.pyqtSlot()
-    def update_GUI(self):
+    def _update_GUI(self):
         """NOTE: 'self.dev.mutex' is not being locked, because we are only
         reading 'state' for displaying purposes. We can do this because 'state'
         members are written and read atomicly.
@@ -297,24 +278,24 @@ class Compax3_servo_qdev(QDeviceIO):
 
     @QtCore.pyqtSlot()
     def process_pbtn_jog_plus_pressed(self):
-        if not self.jog_plus_is_active:
-            self.jog_plus_is_active = True
+        if not self._jog_plus_is_active:
+            self._jog_plus_is_active = True
             self.send(self.dev.jog_plus)
 
     @QtCore.pyqtSlot()
     def process_pbtn_jog_plus_released(self):
-        self.jog_plus_is_active = False
+        self._jog_plus_is_active = False
         self.send(self.dev.stop_motion_but_keep_power)
 
     @QtCore.pyqtSlot()
     def process_pbtn_jog_minus_pressed(self):
-        if not self.jog_minus_is_active:
-            self.jog_minus_is_active = True
+        if not self._jog_minus_is_active:
+            self._jog_minus_is_active = True
             self.send(self.dev.jog_minus)
 
     @QtCore.pyqtSlot()
     def process_pbtn_jog_minus_released(self):
-        self.jog_minus_is_active = False
+        self._jog_minus_is_active = False
         self.send(self.dev.stop_motion_but_keep_power)
 
     @QtCore.pyqtSlot()
@@ -322,10 +303,10 @@ class Compax3_servo_qdev(QDeviceIO):
         self.send(self.dev.stop_motion_and_remove_power)
 
     # --------------------------------------------------------------------------
-    #   connect_signals_to_slots
+    #   _connect_signals_to_slots
     # --------------------------------------------------------------------------
 
-    def connect_signals_to_slots(self):
+    def _connect_signals_to_slots(self):
         # self.send_setpoint.editingFinished.connect(
         #        self.send_setpoint_from_textbox)
 
