@@ -6,8 +6,8 @@
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"  # 0.0.1 was stamped 14-09-2018
-__version__ = "0.0.5"  # 0.0.1 corresponds to prototype 1.0.0
+__date__ = "07-07-2020"
+__version__ = "0.0.6"
 # pylint: disable=bare-except
 
 import sys
@@ -138,7 +138,9 @@ if __name__ == "__main__":
     #   Set up communication threads for the mux
     # --------------------------------------------------------------------------
 
-    mux_qdev = Keysight_3497xA_qdev(mux, MUX_SCANNING_INTERVAL_MS)
+    mux_qdev = Keysight_3497xA_qdev(
+        dev=mux, DAQ_interval_ms=MUX_SCANNING_INTERVAL_MS
+    )
     mux_qdev.start()
 
     # --------------------------------------------------------------------------
