@@ -10,9 +10,9 @@ refer to this device as a multiplexer, or mux.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"  # 0.0.1 was stamped 18-09-2018
-__version__ = "0.0.5"  # 0.0.1 corresponds to prototype 1.0.0
-
+__date__ = "07-07-2020"
+__version__ = "0.0.6"
+# pylint: disable=broad-except
 
 from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
@@ -57,26 +57,15 @@ class Keysight_3497xA_qdev(QDeviceIO):
     These can be incorporated into your application.
 
     All device I/O operations will be offloaded to 'workers', each running in
-    a newly created thread instead of in the main/GUI thread.
-
-        - Worker_DAQ:
-            Periodically acquires data from the device.
-
-        - Worker_jobs:
-            Maintains a thread-safe queue where desired device I/O operations
-            can be put onto, and sends the queued operations first in first out
-            (FIFO) to the device.
+    a newly created thread.
 
     (*): See 'dvg_qdeviceio.QDeviceIO()' for details.
 
     Args:
         dev:
             Reference to a
-            'dvg_devices.Keysight_3497xA_protocol_SCPI.Keysight_3497xA' instance.
-
-        (*) DAQ_interval_ms
-        (*) critical_not_alive_count
-        (*) DAQ_timer_type
+            'dvg_devices.Keysight_3497xA_protocol_SCPI.Keysight_3497xA'
+            instance.
 
         DAQ_postprocess_MUX_data_function (optional, default=None):
             Reference to a user-supplied function that will be called during
@@ -84,10 +73,11 @@ class Keysight_3497xA_qdev(QDeviceIO):
             you can use this function to, e.g., parse out the scan readings into
             separate variables and post-process this data or log it.
 
-    Main methods:
-        (*) start(...)
-        (*) quit()
+        debug:
+            Show debug info in terminal? Warning: Slow! Do not leave on
+            unintentionally.
 
+    Main methods:
         set_table_readings_format:
             TO DO: write description
 
@@ -100,10 +90,6 @@ class Keysight_3497xA_qdev(QDeviceIO):
     Main GUI objects:
         qgrp (PyQt5.QtWidgets.QGroupBox)
 
-    Signals:
-        (*) signal_DAQ_updated()
-        (*) signal_connection_lost()
-
     Slots:
         start_MUX_scan():
             Enable scanning and fetching data of the multiplexer during an
@@ -169,40 +155,16 @@ class Keysight_3497xA_qdev(QDeviceIO):
 
     @QtCore.pyqtSlot()
     def start_MUX_scan(self):
-        """
-        # [DISABLED CODE]
-        # Recreate the worker timer and acquire new samples immediately,
-        # instead of waiting for the next tick to occur of the 'old' timer.
-        # NOTE: Would love to stop the old timer first, but for some strange
-        # reason the very first Qtimer appears to be running in another
-        # thread than the 'worker_state' thread, eventhough the routine in
-        # K3497xA_qdev.__init__ has finished moving the worker_state thread.
-        # When timer is running in another thread than 'this' one, an
-        # exception is thrown py Python saying we can't stop the timer from
-        # another thread. Hence, I reassign a new Qtimer and hope that the
-        # old timer is garbage collected all right.
-        self.timer.stop()  # Does not work 100% of the time!
-        """
+        # TODO: Stop and restart the worker_DAQ timer, such that a scan is
+        # immediately begun, instead of waiting for the next occuring `tick`.
+        # Stopping and starting that timer should occur from within the
+        # worker_DAQ thread, hence implement a `timer_restart` slot in
+        # :class:`dvg-qdeviceio.Worker_DAQ`.
 
         self.is_MUX_scanning = True
         self.signal_DAQ_updated.emit()  # Show we are scanning
         QtWid.QApplication.processEvents()
 
-        """
-        # [DISABLED CODE]
-        # Disabled the recreation of the timer, because of not
-        # understood behavior. The first time iteration of every newly
-        # created QTimer seems to be running in the MAIN thread while
-        # subsequent iterations take place in the Worker_state thread.
-        # This might lead to program instability? Not sure. Simply disabled
-        # for now.
-        self.timer = QtCore.QTimer()            # Create new timer
-        self.timer.setInterval(self.scanning_interval_ms)
-        self.timer.timeout.connect(self.update)
-        self.timer.start()
-        self.update()  # Kickstart at t = 0, because timer doesn't fire now
-        """
-
     # --------------------------------------------------------------------------
     #   stop_scanning
     # --------------------------------------------------------------------------
@@ -273,7 +235,7 @@ class Keysight_3497xA_qdev(QDeviceIO):
         # Optional user-supplied function to run. You can use this function to,
         # e.g., parse out the scan readings into separate variables and
         # post-process this data or log it.
-        if not (self.DAQ_postprocess_MUX_scan_function is None):
+        if self.DAQ_postprocess_MUX_scan_function is not None:
             self.DAQ_postprocess_MUX_scan_function()
 
         if self.worker_DAQ.debug:
@@ -447,7 +409,8 @@ class Keysight_3497xA_qdev(QDeviceIO):
             "%s" % "\n".join(self.dev.SCPI_setup_commands)
         )
         self.qled_scanning_interval_ms.setText(
-            "%i" % self.worker_DAQ._DAQ_interval_ms
+            "%i"
+            % self.worker_DAQ._DAQ_interval_ms  # pylint: disable=protected-access
         )
 
     # --------------------------------------------------------------------------
