@@ -6,8 +6,8 @@ acquisition for a Keysight N8700 power supply (PSU).
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"  # 0.0.1 was stamped 19-09-2018
-__version__ = "0.0.5"  # 0.0.1 corresponds to prototype 1.0.0
+__date__ = "07-07-2020"
+__version__ = "0.0.6"
 
 import numpy as np
 
@@ -48,42 +48,22 @@ class Keysight_N8700_qdev(QDeviceIO):
     These can be incorporated into your application.
 
     All device I/O operations will be offloaded to 'workers', each running in
-    a newly created thread instead of in the main/GUI thread.
-
-        - Worker_DAQ:
-            Periodically acquires data from the device.
-
-        - Worker_jobs:
-            Maintains a thread-safe queue where desired device I/O operations
-            can be put onto, and sends the queued operations first in first out
-            (FIFO) to the device.
+    a newly created thread.
 
     (*): See 'dvg_qdeviceio.QDeviceIO()' for details.
 
     Args:
         dev:
             Reference to a
-            'dvg_devices.Keysight_N8700_protocol_SCPI.Keysight_N8700' instance.
+            'dvg_devices.Keysight_N8700_protocol_SCPI.Keysight_N8700'
+            instance.
 
-        (*) DAQ_interval_ms
-        (*) critical_not_alive_count
-        (*) DAQ_timer_type
-
-    Main methods:
-        (*) start(...)
-        (*) quit()
-
-    Main data attributes:
-        (*) DAQ_update_counter
-        (*) obtained_DAQ_interval_ms
-        (*) obtained_DAQ_rate_Hz
+        debug:
+            Show debug info in terminal? Warning: Slow! Do not leave on
+            unintentionally.
 
     Main GUI objects:
         qgrp (PyQt5.QtWidgets.QGroupBox)
-
-    Signals:
-        (*) signal_DAQ_updated()
-        (*) signal_connection_lost()
     """
 
     signal_GUI_input_field_update = QtCore.pyqtSignal(int)
